import { ClientCtrls } from "../../interface/ClientCtrls";
import { TkWebElement } from "../../interface/TkWebElement";
import { ImplicitWaiter, MultipleElementsOptions, WebElementFinder, WebElementListFinder } from "../../interface/WebElements";
import { UntilElementCondition } from "./ElementConditions";
import { By } from "./Locator";
import { WebElementWd } from "./WebElementWd";
/**
 * List object to wrap the location strategy for finding multiple elements with WebDriverJS
 */
export declare class WebElementListWd<WD> implements WebElementListFinder, ImplicitWaiter {
    private _getElements;
    private _locator;
    readonly browser: ClientCtrls<WD>;
    private createWebElementFromList;
    private shallImplicitlyWait;
    private _description;
    private logger;
    private static shallWaitFor;
    private readonly standardWaiter;
    constructor(_getElements: () => Promise<TkWebElement<WD>[]>, _locator: By, browser: ClientCtrls<WD>, createWebElementFromList: (elementList: WebElementListWd<WD>, browser: ClientCtrls<WD>) => WebElementWd<WD>, shallImplicitlyWait?: boolean);
    /**
     * Send
     */
    /**
     * set the standard wait time for elements to be visible
     * @param {number} timeout - the time to wait until the element is visible
     */
    static set implicitlyWaitFor(timeout: number);
    static get implicitlyWaitFor(): number;
    private getElements;
    /**
     * get the first element of elements list
     * @returns {Promise<TkWebElement<WD>>} the first element
     */
    getHeadOfElementList(): Promise<TkWebElement<WD>>;
    /**
     * find sub elements relative to this current waiter
     * @param locator - selector to find a sub waiter
     */
    element(locator: By): WebElementFinder;
    /**
     * find all sub elements relative to this element
     * @param locator - selector to find all sub elements
     */
    all(locator: By): WebElementListFinder;
    /**
     * wait for condi   tion until interaction with element / element list
     * @param condition - the waiter condition to wait for
     */
    shallWait(condition: UntilElementCondition): WebElementListFinder;
    shallNotImplicitlyWait(): WebElementListFinder;
    count(): Promise<number>;
    click(): Promise<void>;
    isEnabledWaiter(): Promise<boolean[] | boolean>;
    private isEnabledPure;
    isEnabled(options?: MultipleElementsOptions): Promise<boolean[] | boolean>;
    isVisibleWaiter(): Promise<boolean[] | boolean>;
    private isDisplayedPure;
    isVisible(options?: MultipleElementsOptions): Promise<boolean[] | boolean>;
    getText(): Promise<string[]>;
    toWebElement(): WebElementWd<WD>;
    filteredByText(searchText: string): WebElementListFinder;
    called(description: string): WebElementListFinder;
    get description(): string;
    get locatorDescription(): string;
    toString(): string;
}
//# sourceMappingURL=WebElementListWd.d.ts.map